# -*- coding: utf-8 -*-

"""Top-level package for easyimages."""

__author__ = """Jakub Cieslik"""
__email__ = 'kubacieslik@gmail.com'
__version__ = '0.2.0'

from .easyimages import EasyImage, EasyImageList, bbox
